ete2.treeview.faces.ValidationFace

Package ete2 :: Package treeview :: Module faces :: Class ValidationFace |
[hide private]
[frames] | no frames]

# Class ValidationFace

source code

    object --+
             |
          Face --+
                 |
                ValidationFace

Creates a new clustering validation face

Instance Methods | [hide private]
__init__(self, fsize=10) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
update_pixmap(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`
Inherited from Face
_height(self) | source code
_size(self) | source code
_width(self) | source code
load_pixmap_from_file(self, filename) | source code

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, fsize=10) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### update_pixmap(self) | source code
Overrides: Face.update_pixmap